@@ -1,16 +1,11 @@
-import pytest
-
+from cattrs import BaseConverter
 from cattrs.dispatch import FunctionDispatch
-from cattrs.errors import StructureHandlerNotFoundError
 
 
 def test_function_dispatch():
-    dispatch = FunctionDispatch()
+    dispatch = FunctionDispatch(BaseConverter())
 
-    with pytest.raises(StructureHandlerNotFoundError) as exc:
-        dispatch.dispatch(float)
-
-    assert exc.value.type_ is float
+    assert dispatch.dispatch(float) is None
 
     test_func = object()
 
@@ -20,9 +15,9 @@ def test_function_dispatch():
 
 
 def test_function_clears_cache_after_function_added():
-    dispatch = FunctionDispatch()
+    dispatch = FunctionDispatch(BaseConverter())
 
-    class Foo(object):
+    class Foo:
         pass
 
     Foo()
